@@ -1,7 +1,15 @@
+#
+# This file is part of Dist-Zilla-Plugin-ConsistentVersionTest
+#
+# This software is copyright (c) 2010 by Dave Rolsky.
+#
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+#
 package Dist::Zilla::Plugin::ConsistentVersionTest;
-BEGIN {
-  $Dist::Zilla::Plugin::ConsistentVersionTest::VERSION = '0.02';
-}
+our $AUTHORITY = 'cpan:RSRCHBOY';
+# git description: 091ea5c
+$Dist::Zilla::Plugin::ConsistentVersionTest::VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -11,6 +19,19 @@ use Test::ConsistentVersion;
 use Moose;
 
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::PrereqSource';
+
+
+sub register_prereqs {
+    my $self = shift @_;
+
+    $self->zilla->register_prereqs(
+        { phase => 'develop' },
+        'Test::ConsistentVersion' => 0,
+    );
+
+    return;
+}
 
 no Moose;
 
@@ -20,18 +41,19 @@ __PACKAGE__->meta->make_immutable;
 
 # ABSTRACT: Adds a release test to ensure that all modules have the same $VERSION
 
-
-
-
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Dave Rolsky Chris Weyl
+
 =head1 NAME
 
 Dist::Zilla::Plugin::ConsistentVersionTest - Adds a release test to ensure that all modules have the same $VERSION
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of Dist::Zilla::Plugin::ConsistentVersionTest - released April 01, 2017 as part of Dist-Zilla-Plugin-ConsistentVersionTest.
 
 =head1 SYNOPSIS
 
@@ -46,18 +68,19 @@ following files
 
   xt/release/consistent-version.t
 
-=head1 SUPPORT
+=head1 METHODS
 
-Please report any bugs or feature requests to
-C<bug-dist-zilla-plugin-consistentversiontest@rt.cpan.org>, or through the web
-interface at L<http://rt.cpan.org>. I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+=head2 register_prereqs
+
+Registers a 'develop' phase requirement for L<Test::ConsistentVersion> with the
+L<Dist::Zilla> object.
 
 =head1 DONATIONS
 
-If you'd like to thank me for the work I've done on this module, please
-consider making a "donation" to me via PayPal. I spend a lot of free time
-creating free software, and would appreciate any support you'd care to offer.
+If you'd like to thank me (the author, Dave Rolsky) for the work I've done on
+this module, please consider making a "donation" to me via PayPal. I spend a
+lot of free time creating free software, and would appreciate any support
+you'd care to offer.
 
 Please note that B<I am not suggesting that you must do this> in order for me
 to continue working on this particular software. I will continue to do so,
@@ -70,9 +93,24 @@ on free software full time, which seems unlikely at best.
 To donate, log into PayPal and send money to autarch@urth.org or use the
 button on this page: L<http://www.urth.org/~autarch/fs-donation.html>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/RsrchBoy/Dist-Zilla-Plugin-ConsistentVersionTest/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-  Dave Rolsky <autarch@urth.org>
+Dave Rolsky <autarch@urth.org>
+
+=head1 CONTRIBUTOR
+
+=for stopwords Chris Weyl
+
+Chris Weyl <rsrchboy@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -83,7 +121,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 ___[ xt/release/consistent-version.t ]___
 use strict;
